==================================================================
 `xoutil.dim.meta`:mod: -- Meta-definitions for concrete numbers.
==================================================================

.. automodule:: xoutil.dim.meta
   :members: QuantityType, Signature, Quantity, Scalar

.. object:: UNIT

   This the value 1, but it's given this name to emphasize it's the canonical
   unit for a quantity type.
